<p align="center"> <img src="src/wttrman/resources/images/wttrman-256.png" /> </p>

## Donations

- [Buy Me A Coffee](https://www.buymeacoffee.com/KingKairos)
- [GitHub Sponsors](https://github.com/sponsors/melvinquick)

## Purpose

The general purpose of this app was to make a GUI front-end to [Wttr](https://wttr.in) to make it easier to get a condensed weather report for a multitude of locations across the United States.

## Install/Uninstall

Install: `curl -s https://codeberg.org/melvinquick/wttrman/raw/branch/main/install.py | python3 -`  
Uninstall: `curl -s https://codeberg.org/melvinquick/wttrman/raw/branch/main/uninstall.py | python3 -`

![app_install_uninstall_showcase.gif](src/wttrman/resources/gifs/app_install_uninstall_showcase.gif)

## App Showcase

![app_showcase.gif](src/wttrman/resources/gifs/app_showcase.gif)

## Useful Information

- [Project Goals](https://codeberg.org/melvinquick/wttrman/projects/13315)
- [Latest Release](https://codeberg.org/melvinquick/wttrman/releases/latest)
- [Releases](https://codeberg.org/melvinquick/wttrman/releases)
